﻿using Newtonsoft.Json;
using StockInQuiry.Dto;
using System;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using System.Windows.Forms;
using Excel = Microsoft.Office.Interop.Excel;

namespace StockInQuiry
{
    public partial class BomComparisonForm : Form
    {
        private string _environment;
        public BomComparisonForm(string materialCode,string environment)
        {
            _environment = environment;
            InitializeComponent();
            initialization(materialCode);
        }

        private async Task initialization(string materialCode)
        {
            if (string.IsNullOrEmpty(materialCode))
            {
                return;
            }
            materialCodetextBox1.Text = materialCode;
            materialCodetextBox2.Text = materialCode;
            await GetVersion("MaterialCode1", materialCode);
            await GetVersion("MaterialCode2", materialCode);

            var materialCode1 = materialCodetextBox1.Text;
            var materialCode2 = materialCodetextBox2.Text;
            var version1 = versionComboBox1.Text;
            var version2 = versionComboBox2.Text;

            bool condition1 = !string.IsNullOrEmpty(materialCode1) && !string.IsNullOrEmpty(version1);
            bool condition2 = !string.IsNullOrEmpty(materialCode2) && !string.IsNullOrEmpty(version2);

            if (condition1 == false && condition2 == false)
            {
                // 两组输入都不满足要求，进入此逻辑
                MessageBox.Show("两组物料编码和版本均为空，请输入至少一组有效的物料编码和版本。");
                return;
            }

            if (condition1 == true)
            {
                GetBom("MaterialCode1", materialCode1, version1);
            }

            if (condition2 == true)
            {
                GetBom("MaterialCode2", materialCode2, version2);
            }

        }

        private void SimulateButtonClick()
        {
            // 假设 getVersionbutton 是你的按钮控件
            getBombutton.PerformClick();
        }

        private void getVersionbutton_Click(object sender, EventArgs e)
        {
            var materialCode1 = materialCodetextBox1.Text;
            var materialCode2 = materialCodetextBox2.Text;

            if (string.IsNullOrEmpty(materialCode1) && string.IsNullOrEmpty(materialCode2))
            {
                MessageBox.Show("两组物料编码均为空，请输入至少一组有效的物料编码。");
                return;
            }

            if (!string.IsNullOrEmpty(materialCode1))
            {
                GetVersion("MaterialCode1", materialCode1);
                dataGridView1.Rows.Clear();// 清空现有行
                dataGridView3.Rows.Clear();// 清空现有行
            }


            if (!string.IsNullOrEmpty(materialCode2))
            {
                GetVersion("MaterialCode2", materialCode2);
                dataGridView2.Rows.Clear();// 清空现有行
                dataGridView3.Rows.Clear();// 清空现有行
            }
        }


        private async Task<List<MaterialVersionsData>> GetVersion(string type, string materialCode)
        {
            string url = _environment + "api/stockInquiry/pdmMaterialVersions/" + materialCode;
            using (HttpClient client = new HttpClient())
            {
                try
                {
                    HttpResponseMessage response = await client.GetAsync(url);
                    response.EnsureSuccessStatusCode();

                    string content = await response.Content.ReadAsStringAsync();
                    MaterialVersions result = JsonConvert.DeserializeObject<MaterialVersions>(content);
                    var data = result.result;
                    if (type == "MaterialCode1")
                    {
                        versionComboBox1.Items.Clear(); // 清空现有项
                        foreach (var item in data)
                        {
                            versionComboBox1.Items.Add($"{item.Version_index}  {item.Version}");
                        }
                        if (versionComboBox1.Items.Count > 0)
                        {
                            versionComboBox1.SelectedIndex = 0;
                        }
                    }
                    if (type == "MaterialCode2")
                    {
                        versionComboBox2.Items.Clear(); // 清空现有项
                        foreach (var item in data)
                        {
                            versionComboBox2.Items.Add($"{item.Version_index}  {item.Version}");
                        }
                        if (versionComboBox2.Items.Count > 0)
                        {
                            versionComboBox2.SelectedIndex = 0;
                        }
                    }
                    return data;

                }
                catch (HttpRequestException e)
                {
                    MessageBox.Show($"Request failed: {e.Message}");
                    return null;
                }
            }
        }

        private void getBombutton_Click(object sender, EventArgs e)
        {
            var materialCode1 = materialCodetextBox1.Text;
            var materialCode2 = materialCodetextBox2.Text;
            var version1 = versionComboBox1.Text;
            var version2 = versionComboBox2.Text;

            bool condition1 = !string.IsNullOrEmpty(materialCode1) && !string.IsNullOrEmpty(version1);
            bool condition2 = !string.IsNullOrEmpty(materialCode2) && !string.IsNullOrEmpty(version2);

            if (condition1 == false && condition2 == false)
            {
                // 两组输入都不满足要求，进入此逻辑
                MessageBox.Show("两组物料编码和版本均为空，请输入至少一组有效的物料编码和版本。");
                return;
            }

            if (condition1 == true)
            {
                GetBom("MaterialCode1", materialCode1, version1);
            }

            if (condition2 == true)
            {
                GetBom("MaterialCode2", materialCode2, version2);
            }



        }

        private async void GetBom(string type, string materialCode, string version)
        {
            string url = _environment + "api/stockInquiry/getPdmMaterialBom/" + materialCode + '/' + version;

            using (HttpClient client = new HttpClient())
            {
                try
                {

                    HttpResponseMessage response = await client.GetAsync(url);
                    response.EnsureSuccessStatusCode();

                    string content = await response.Content.ReadAsStringAsync();

                    PdmMaterialBom result = JsonConvert.DeserializeObject<PdmMaterialBom>(content);
                    var data = result.result;
                    if (type == "MaterialCode1")
                    {
                        // 清空现有行
                        dataGridView1.Rows.Clear();

                        // 重新添加数据行
                        foreach (var item in data)
                        {
                            int index = dataGridView1.Rows.Add();
                            dataGridView1.Rows[index].Cells["物料编码1"].Value = item.PartNumber;
                            dataGridView1.Rows[index].Cells["名称1"].Value = item.Description;
                            dataGridView1.Rows[index].Cells["数量1"].Value = item.QtyManual;
                            dataGridView1.Rows[index].Cells["代号1"].Value = item.fld005747;
                            dataGridView1.Rows[index].Cells["品牌1"].Value = item.fld005590;
                            dataGridView1.Rows[index].Cells["材质1"].Value = item.fld005587;
                            dataGridView1.Rows[index].Cells["表面处理1"].Value = item.fld006325;
                            dataGridView1.Rows[index].Cells["单位1"].Value = item.fld005744;
                            dataGridView1.Rows[index].Cells["修订版1"].Value = item.childVersion;
                            dataGridView1.Rows[index].Cells["库存1"].Value = item.fld006928;
                            dataGridView1.Rows[index].Cells["预留1"].Value = item.fld006929;
                            dataGridView1.Rows[index].Cells["未清采购申请数量1"].Value = item.fld006930;
                            dataGridView1.Rows[index].Cells["未清采购订单数量1"].Value = item.fld006931;
                        }
                    }

                    if (type == "MaterialCode2")
                    {
                        // 清空现有行
                        dataGridView2.Rows.Clear();

                        // 重新添加数据行
                        foreach (var item in data)
                        {
                            int index = dataGridView2.Rows.Add();
                            dataGridView2.Rows[index].Cells["物料编码2"].Value = item.PartNumber;
                            dataGridView2.Rows[index].Cells["名称2"].Value = item.Description;
                            dataGridView2.Rows[index].Cells["数量2"].Value = item.QtyManual;
                            dataGridView2.Rows[index].Cells["代号2"].Value = item.fld005747;
                            dataGridView2.Rows[index].Cells["品牌2"].Value = item.fld005590;
                            dataGridView2.Rows[index].Cells["材质2"].Value = item.fld005587;
                            dataGridView2.Rows[index].Cells["表面处理2"].Value = item.fld006325;
                            dataGridView2.Rows[index].Cells["单位2"].Value = item.fld005744;
                            dataGridView2.Rows[index].Cells["修订版2"].Value = item.childVersion;
                            dataGridView2.Rows[index].Cells["库存2"].Value = item.fld006928;
                            dataGridView2.Rows[index].Cells["预留2"].Value = item.fld006929;
                            dataGridView2.Rows[index].Cells["未清采购申请数量2"].Value = item.fld006930;
                            dataGridView2.Rows[index].Cells["未清采购订单数量2"].Value = item.fld006931;
                        }
                    }


                }
                catch (HttpRequestException e)
                {
                    MessageBox.Show($"请求失败: {e.Message}");
                }
            }
        }

        private void materialCodetextBox1_TextChanged(object sender, EventArgs e)
        {
            versionComboBox1.Items.Clear(); // 清空现有项

            dataGridView1.Rows.Clear();// 清空现有行
            dataGridView3.Rows.Clear();// 清空现有行
        }

        private void materialCodetextBox2_TextChanged(object sender, EventArgs e)
        {
            versionComboBox2.Items.Clear(); // 清空现有项

            dataGridView2.Rows.Clear();// 清空现有行
            dataGridView3.Rows.Clear();// 清空现有行
        }

        private void comparisonButton_Click(object sender, EventArgs e)
        {
            List<PdmMaterialBomData> list1 = new List<PdmMaterialBomData>();
            List<PdmMaterialBomData> list2 = new List<PdmMaterialBomData>();
            List<ComparedBomResult> list3 = new List<ComparedBomResult>();

            foreach (DataGridViewRow row in dataGridView1.Rows)
            {
                if (!row.IsNewRow)
                {
                    PdmMaterialBomData item = new PdmMaterialBomData();

                    // 假设 OrderIndex 不需要从 DataGridView 中获取，可根据实际情况修改
                    item.OrderIndex = 0;

                    item.PartNumber = row.Cells["物料编码1"].Value?.ToString();
                    item.Description = row.Cells["名称1"].Value?.ToString();

                    if (float.TryParse(row.Cells["数量1"].Value?.ToString(), out float qtyManual))
                    {
                        item.QtyManual = qtyManual;
                    }

                    item.fld005747 = row.Cells["代号1"].Value?.ToString();
                    item.fld005590 = row.Cells["品牌1"].Value?.ToString();
                    item.fld005587 = row.Cells["材质1"].Value?.ToString();
                    item.fld006325 = row.Cells["表面处理1"].Value?.ToString();
                    item.fld005744 = row.Cells["单位1"].Value?.ToString();

                    item.childVersion = row.Cells["修订版1"].Value?.ToString();

                    //if (int.TryParse(row.Cells["修订版1"].Value?.ToString(), out int childVersion))
                    //{
                    //    item.childVersion = childVersion;
                    //}

                    list1.Add(item);
                }
            }

            foreach (DataGridViewRow row in dataGridView2.Rows)
            {
                if (!row.IsNewRow)
                {
                    PdmMaterialBomData item = new PdmMaterialBomData();

                    // 假设 OrderIndex 不需要从 DataGridView 中获取，可根据实际情况修改
                    item.OrderIndex = 0;

                    item.PartNumber = row.Cells["物料编码2"].Value?.ToString();
                    item.Description = row.Cells["名称2"].Value?.ToString();

                    if (float.TryParse(row.Cells["数量2"].Value?.ToString(), out float qtyManual))
                    {
                        item.QtyManual = qtyManual;
                    }

                    item.fld005747 = row.Cells["代号2"].Value?.ToString();
                    item.fld005590 = row.Cells["品牌2"].Value?.ToString();
                    item.fld005587 = row.Cells["材质2"].Value?.ToString();
                    item.fld006325 = row.Cells["表面处理2"].Value?.ToString();
                    item.fld005744 = row.Cells["单位2"].Value?.ToString();

                    item.childVersion = row.Cells["修订版2"].Value?.ToString();

                    //if (int.TryParse(row.Cells["修订版2"].Value?.ToString(), out int childVersion))
                    //{
                    //    item.childVersion = childVersion;
                    //}

                    list2.Add(item);
                }
            }

            foreach (var item in list1)
            {
                ComparedBomResult ComparedBomResultData = new ComparedBomResult();

                //BOM对比-修改
                var bomChange = list2.Where(x => x.PartNumber == item.PartNumber).FirstOrDefault();
                if (bomChange != null)
                {
                    //数量未变更，版本未变更
                    if (item.QtyManual == bomChange.QtyManual && item.childVersion == bomChange.childVersion)
                    {
                        continue;
                    }
                    ComparedBomResultData.PartNumber = item.PartNumber;
                    ComparedBomResultData.Description = item.Description;
                    ComparedBomResultData.fld005747 = item.fld005747;
                    ComparedBomResultData.fld005590 = item.fld005590;
                    ComparedBomResultData.fld005587 = item.fld005587;
                    ComparedBomResultData.fld006325 = item.fld006325;
                    ComparedBomResultData.fld005744 = item.fld005744;
                    ComparedBomResultData.fld006928 = item.fld006928;
                    ComparedBomResultData.fld006929 = item.fld006929;
                    ComparedBomResultData.fld006930 = item.fld006930;
                    ComparedBomResultData.fld006931 = item.fld006931;
                    //数量、版本都存在变更
                    if (item.QtyManual != bomChange.QtyManual && item.childVersion != bomChange.childVersion)
                    {
                        ComparedBomResultData.changeType = "修改";
                        ComparedBomResultData.isVersionChange = "是";

                        //ComparedBomResultData.preCompareQtyManual = item.QtyManual;
                        //ComparedBomResultData.postCompareQtyManual = bomChange.QtyManual;
                        ComparedBomResultData.preCompareQtyManual = bomChange.QtyManual;
                        ComparedBomResultData.postCompareQtyManual = item.QtyManual;

                        //ComparedBomResultData.preCompareVersion = item.childVersion;
                        //ComparedBomResultData.postCompareVersion = bomChange.childVersion;
                        ComparedBomResultData.preCompareVersion = bomChange.childVersion;
                        ComparedBomResultData.postCompareVersion = item.childVersion;

                    }
                    //数量存在变更，版本未变更
                    if (item.QtyManual != bomChange.QtyManual && item.childVersion == bomChange.childVersion)
                    {
                        ComparedBomResultData.changeType = "修改";

                        //ComparedBomResultData.preCompareQtyManual = item.QtyManual;
                        //ComparedBomResultData.postCompareQtyManual = bomChange.QtyManual;
                        ComparedBomResultData.preCompareQtyManual = bomChange.QtyManual;
                        ComparedBomResultData.postCompareQtyManual = item.QtyManual;

                        //ComparedBomResultData.preCompareVersion = item.childVersion;
                        //ComparedBomResultData.postCompareVersion = bomChange.childVersion;
                        ComparedBomResultData.preCompareVersion = bomChange.childVersion;
                        ComparedBomResultData.postCompareVersion = item.childVersion;
                    }
                    //数量未变更，版本存在变更
                    if (item.QtyManual == bomChange.QtyManual && item.childVersion != bomChange.childVersion)
                    {
                        ComparedBomResultData.changeType = "修改";
                        ComparedBomResultData.isVersionChange = "是";

                        //ComparedBomResultData.preCompareQtyManual = item.QtyManual;
                        //ComparedBomResultData.postCompareQtyManual = bomChange.QtyManual;
                        ComparedBomResultData.preCompareQtyManual = bomChange.QtyManual;
                        ComparedBomResultData.postCompareQtyManual = item.QtyManual;

                        //ComparedBomResultData.preCompareVersion = item.childVersion;
                        //ComparedBomResultData.postCompareVersion = bomChange.childVersion;
                        ComparedBomResultData.preCompareVersion = bomChange.childVersion;
                        ComparedBomResultData.postCompareVersion = item.childVersion;
                    }
                    list3.Add(ComparedBomResultData);
                }

                //BOM对比-新增
                if (bomChange == null)
                {
                    ComparedBomResultData.PartNumber = item.PartNumber;
                    ComparedBomResultData.Description = item.Description;
                    ComparedBomResultData.fld005747 = item.fld005747;
                    ComparedBomResultData.fld005590 = item.fld005590;
                    ComparedBomResultData.fld005587 = item.fld005587;
                    ComparedBomResultData.fld006325 = item.fld006325;
                    ComparedBomResultData.fld005744 = item.fld005744;
                    ComparedBomResultData.fld006928 = item.fld006928;
                    ComparedBomResultData.fld006929 = item.fld006929;
                    ComparedBomResultData.fld006930 = item.fld006930;
                    ComparedBomResultData.fld006931 = item.fld006931;

                    //ComparedBomResultData.preCompareQtyManual = item.QtyManual;
                    //ComparedBomResultData.preCompareVersion = item.childVersion;
                    ComparedBomResultData.postCompareQtyManual = item.QtyManual;
                    ComparedBomResultData.postCompareVersion = item.childVersion;


                    ComparedBomResultData.changeType = "新增";
                    list3.Add(ComparedBomResultData);
                }
               
            }

            //BOM对比-删除
            foreach (var item2 in list2)
            {
                ComparedBomResult ComparedBomResultData = new ComparedBomResult();
                var bomChange = list1.Where(x => x.PartNumber == item2.PartNumber).FirstOrDefault();
                if (bomChange == null)
                {
                    ComparedBomResultData.PartNumber = item2.PartNumber;
                    ComparedBomResultData.Description = item2.Description;
                    ComparedBomResultData.fld005747 = item2.fld005747;
                    ComparedBomResultData.fld005590 = item2.fld005590;
                    ComparedBomResultData.fld005587 = item2.fld005587;
                    ComparedBomResultData.fld006325 = item2.fld006325;
                    ComparedBomResultData.fld005744 = item2.fld005744;
                    ComparedBomResultData.fld006928 = item2.fld006928;
                    ComparedBomResultData.fld006929 = item2.fld006929;
                    ComparedBomResultData.fld006930 = item2.fld006930;
                    ComparedBomResultData.fld006931 = item2.fld006931;
                    //ComparedBomResultData.preCompareQtyManual = item2.QtyManual;
                    //ComparedBomResultData.preCompareVersion = item2.childVersion;
                    ComparedBomResultData.preCompareQtyManual = item2.QtyManual;
                    ComparedBomResultData.preCompareVersion = item2.childVersion;

                    ComparedBomResultData.changeType = "删除";
                    list3.Add(ComparedBomResultData);
                }
                
            }
            if (list3.Count != 0)
            {
                // 清空现有行
                dataGridView3.Rows.Clear();

                // 重新添加数据行
                foreach (var item in list3)
                {
                    int index = dataGridView3.Rows.Add();
                    dataGridView3.Rows[index].Cells["物料编码3"].Value = item.PartNumber;
                    dataGridView3.Rows[index].Cells["名称3"].Value = item.Description;
                    
                    dataGridView3.Rows[index].Cells["代号3"].Value = item.fld005747;
                    dataGridView3.Rows[index].Cells["品牌3"].Value = item.fld005590;
                    dataGridView3.Rows[index].Cells["材质3"].Value = item.fld005587;
                    dataGridView3.Rows[index].Cells["表面处理3"].Value = item.fld006325;
                    dataGridView3.Rows[index].Cells["单位3"].Value = item.fld005744;
                    
                    dataGridView3.Rows[index].Cells["库存3"].Value = item.fld006928;
                    dataGridView3.Rows[index].Cells["预留3"].Value = item.fld006929;
                    dataGridView3.Rows[index].Cells["未清采购申请数量3"].Value = item.fld006930;
                    dataGridView3.Rows[index].Cells["未清采购订单数量3"].Value = item.fld006931;


                    dataGridView3.Rows[index].Cells["对比前数量3"].Value = item.preCompareQtyManual;
                    dataGridView3.Rows[index].Cells["对比后数量3"].Value = item.postCompareQtyManual;
                    dataGridView3.Rows[index].Cells["对比前修订版3"].Value = item.preCompareVersion;
                    dataGridView3.Rows[index].Cells["对比后修订版3"].Value = item.postCompareVersion;

                    dataGridView3.Rows[index].Cells["对比类型3"].Value = item.changeType;
                    dataGridView3.Rows[index].Cells["是否版本变更3"].Value = item.isVersionChange;

                    // 设置行颜色
                    if (item.changeType == "新增")
                    {
                        System.Drawing.Color customColor = System.Drawing.Color.FromArgb(122, 244, 122);
                        dataGridView3.Rows[index].DefaultCellStyle.BackColor = customColor;
                    }

                    if (item.changeType == "修改")
                    {
                        System.Drawing.Color customColor = System.Drawing.Color.FromArgb(255, 192, 128);
                        dataGridView3.Rows[index].DefaultCellStyle.BackColor = customColor;
                    }

                    if (item.changeType == "删除")
                    {
                        System.Drawing.Color customColor = System.Drawing.Color.FromArgb(244, 122, 122);
                        dataGridView3.Rows[index].DefaultCellStyle.BackColor = customColor;
                    }
                }
            }
        }

        private void versionComboBox1_TextChanged(object sender, EventArgs e)
        {
            dataGridView1.Rows.Clear();// 清空现有行
            dataGridView3.Rows.Clear();// 清空现有行
        }

        private void versionComboBox2_TextChanged(object sender, EventArgs e)
        {
            dataGridView2.Rows.Clear();// 清空现有行
            dataGridView3.Rows.Clear();// 清空现有行
        }

        private void dataGridView1_RowPostPaint(object sender, DataGridViewRowPostPaintEventArgs e)
        {
            //自动编号，与数据无关
            Rectangle rectangle = new Rectangle(e.RowBounds.Location.X,
               e.RowBounds.Location.Y,
               dataGridView1.RowHeadersWidth - 4,
               e.RowBounds.Height);
            TextRenderer.DrawText(e.Graphics,
                  (e.RowIndex + 1).ToString(),
                   dataGridView1.RowHeadersDefaultCellStyle.Font,
                   rectangle,
                   dataGridView1.RowHeadersDefaultCellStyle.ForeColor,
                   TextFormatFlags.VerticalCenter | TextFormatFlags.Right);
        }

        private void dataGridView2_RowPostPaint(object sender, DataGridViewRowPostPaintEventArgs e)
        {
            //自动编号，与数据无关
            Rectangle rectangle = new Rectangle(e.RowBounds.Location.X,
               e.RowBounds.Location.Y,
               dataGridView1.RowHeadersWidth - 4,
               e.RowBounds.Height);
            TextRenderer.DrawText(e.Graphics,
                  (e.RowIndex + 1).ToString(),
                   dataGridView1.RowHeadersDefaultCellStyle.Font,
                   rectangle,
                   dataGridView1.RowHeadersDefaultCellStyle.ForeColor,
                   TextFormatFlags.VerticalCenter | TextFormatFlags.Right);
        }

        private void dataGridView3_RowPostPaint(object sender, DataGridViewRowPostPaintEventArgs e)
        {
            //自动编号，与数据无关
            Rectangle rectangle = new Rectangle(e.RowBounds.Location.X,
               e.RowBounds.Location.Y,
               dataGridView1.RowHeadersWidth - 4,
               e.RowBounds.Height);
            TextRenderer.DrawText(e.Graphics,
                  (e.RowIndex + 1).ToString(),
                   dataGridView1.RowHeadersDefaultCellStyle.Font,
                   rectangle,
                   dataGridView1.RowHeadersDefaultCellStyle.ForeColor,
                   TextFormatFlags.VerticalCenter | TextFormatFlags.Right);
        }

        private void ExportToExcel(DataGridView dataGridView)
        {
            // 创建 Excel 应用程序对象
            Excel.Application excelApp = new Excel.Application();
            Excel.Workbook workbook = excelApp.Workbooks.Add();
            Excel.Worksheet worksheet = workbook.ActiveSheet;

            try
            {
                // 导出列标题
                for (int i = 0; i < dataGridView.Columns.Count; i++)
                {
                    worksheet.Cells[1, i + 1] = dataGridView.Columns[i].HeaderText;
                    // 设置列标题字体为微软雅黑
                    worksheet.Cells[1, i + 1].Font.Name = "微软雅黑";
                }

                // 导出数据行
                for (int i = 0; i < dataGridView.Rows.Count; i++)
                {
                    for (int j = 0; j < dataGridView.Columns.Count; j++)
                    {
                        if (dataGridView.Rows[i].Cells[j].Value != null)
                        {
                            worksheet.Cells[i + 2, j + 1] = dataGridView.Rows[i].Cells[j].Value.ToString();
                            // 设置单元格格式为文本，防止数字显示为科学计数法
                            worksheet.Cells[i + 2, j + 1].NumberFormat = "@";
                            // 设置单元格字体为微软雅黑
                            worksheet.Cells[i + 2, j + 1].Font.Name = "微软雅黑";
                        }
                    }
                }

                // 获取数据区域
                Excel.Range range = worksheet.Range[worksheet.Cells[1, 1], worksheet.Cells[dataGridView.Rows.Count + 1, dataGridView.Columns.Count]];

                // 设置边框样式
                range.Borders.LineStyle = Excel.XlLineStyle.xlContinuous;
                range.Borders.Weight = Excel.XlBorderWeight.xlThin;

                // 自动调整列宽
                range.EntireColumn.AutoFit();

                // 保存 Excel 文件
                SaveFileDialog saveFileDialog = new SaveFileDialog();
                saveFileDialog.Filter = "Excel 文件 (*.xlsx)|*.xlsx";
                saveFileDialog.Title = "保存 Excel 文件";
                if (saveFileDialog.ShowDialog() == DialogResult.OK)
                {
                    workbook.SaveAs(saveFileDialog.FileName);
                    MessageBox.Show("Bom对比结果，已成功导出到 Excel 文件！");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("导出数据时发生错误：" + ex.Message);
            }
            finally
            {
                // 释放资源
                workbook.Close();
                excelApp.Quit();
                System.Runtime.InteropServices.Marshal.ReleaseComObject(worksheet);
                System.Runtime.InteropServices.Marshal.ReleaseComObject(workbook);
                System.Runtime.InteropServices.Marshal.ReleaseComObject(excelApp);
            }
        }

        //private void ExportToExcel(DataGridView dataGridView)
        //{
        //    // 创建一个新的工作簿
        //    IWorkbook workbook = new XSSFWorkbook();
        //    // 创建一个工作表
        //    ISheet sheet = workbook.CreateSheet("Sheet1");

        //    try
        //    {
        //        // 导出列标题
        //        IRow headerRow = sheet.CreateRow(0);
        //        for (int i = 0; i < dataGridView.Columns.Count; i++)
        //        {
        //            ICell cell = headerRow.CreateCell(i);
        //            cell.SetCellValue(dataGridView.Columns[i].HeaderText);
        //        }

        //        // 导出数据行
        //        for (int i = 0; i < dataGridView.Rows.Count; i++)
        //        {
        //            IRow dataRow = sheet.CreateRow(i + 1);
        //            for (int j = 0; j < dataGridView.Columns.Count; j++)
        //            {
        //                if (dataGridView.Rows[i].Cells[j].Value != null)
        //                {
        //                    ICell cell = dataRow.CreateCell(j);
        //                    cell.SetCellValue(dataGridView.Rows[i].Cells[j].Value.ToString());
        //                }
        //            }
        //        }

        //        // 设置边框样式
        //        for (int rowIndex = 0; rowIndex <= dataGridView.Rows.Count; rowIndex++)
        //        {
        //            IRow row = sheet.GetRow(rowIndex);
        //            if (row != null)
        //            {
        //                for (int cellIndex = 0; cellIndex < dataGridView.Columns.Count; cellIndex++)
        //                {
        //                    ICell cell = row.GetCell(cellIndex);
        //                    if (cell != null)
        //                    {
        //                        ICellStyle style = workbook.CreateCellStyle();
        //                        style.BorderTop = BorderStyle.Thin;
        //                        style.BorderLeft = BorderStyle.Thin;
        //                        style.BorderRight = BorderStyle.Thin;
        //                        style.BorderBottom = BorderStyle.Thin;
        //                        cell.CellStyle = style;
        //                    }
        //                }
        //            }
        //        }

        //        // 自动调整列宽
        //        for (int i = 0; i < dataGridView.Columns.Count; i++)
        //        {
        //            sheet.AutoSizeColumn(i);
        //        }

        //        // 保存 Excel 文件
        //        SaveFileDialog saveFileDialog = new SaveFileDialog();
        //        saveFileDialog.Filter = "Excel 文件 (*.xlsx)|*.xlsx";
        //        saveFileDialog.Title = "保存 Excel 文件";
        //        if (saveFileDialog.ShowDialog() == DialogResult.OK)
        //        {
        //            using (FileStream fs = new FileStream(saveFileDialog.FileName, FileMode.Create, FileAccess.Write))
        //            {
        //                workbook.Write(fs);
        //            }
        //            MessageBox.Show("数据已成功导出到 Excel 文件！");
        //        }
        //    }
        //    catch (Exception ex)
        //    {
        //        MessageBox.Show("导出数据时发生错误：" + ex.Message);
        //    }
        //    finally
        //    {
        //        // 关闭工作簿
        //        workbook.Close();
        //    }
        //}







        //private void ExportToExcel(DataGridView dataGridView)
        //{
        //    using (ExcelPackage package = new ExcelPackage())
        //    {
        //        ExcelWorksheet worksheet = package.Workbook.Worksheets.Add("Sheet1");

        //        try
        //        {
        //            // 导出列标题
        //            for (int i = 0; i < dataGridView.Columns.Count; i++)
        //            {
        //                worksheet.Cells[1, i + 1].Value = dataGridView.Columns[i].HeaderText;
        //            }

        //            // 导出数据行
        //            for (int i = 0; i < dataGridView.Rows.Count; i++)
        //            {
        //                for (int j = 0; j < dataGridView.Columns.Count; j++)
        //                {
        //                    if (dataGridView.Rows[i].Cells[j].Value != null)
        //                    {
        //                        worksheet.Cells[i + 2, j + 1].Value = dataGridView.Rows[i].Cells[j].Value.ToString();
        //                        // 设置单元格格式为文本，防止数字显示为科学计数法
        //                        worksheet.Cells[i + 2, j + 1].Style.Numberformat.Format = "@";
        //                    }
        //                }
        //            }

        //            // 获取数据区域
        //            var range = worksheet.Cells[1, 1, dataGridView.Rows.Count + 1, dataGridView.Columns.Count];

        //            // 设置边框样式
        //            range.Style.Border.Top.Style = OfficeOpenXml.Style.ExcelBorderStyle.Thin;
        //            range.Style.Border.Left.Style = OfficeOpenXml.Style.ExcelBorderStyle.Thin;
        //            range.Style.Border.Right.Style = OfficeOpenXml.Style.ExcelBorderStyle.Thin;
        //            range.Style.Border.Bottom.Style = OfficeOpenXml.Style.ExcelBorderStyle.Thin;

        //            // 自动调整列宽
        //            worksheet.Cells.AutoFitColumns();

        //            // 保存 Excel 文件
        //            SaveFileDialog saveFileDialog = new SaveFileDialog();
        //            saveFileDialog.Filter = "Excel 文件 (*.xlsx)|*.xlsx";
        //            saveFileDialog.Title = "保存 Excel 文件";
        //            if (saveFileDialog.ShowDialog() == DialogResult.OK)
        //            {
        //                FileInfo file = new FileInfo(saveFileDialog.FileName);
        //                package.SaveAs(file);
        //                MessageBox.Show("数据已成功导出到 Excel 文件！");
        //            }
        //        }
        //        catch (Exception ex)
        //        {
        //            MessageBox.Show("导出数据时发生错误：" + ex.Message);
        //        }
        //    }
        //}



        private void button1_Click(object sender, EventArgs e)
        {
            ExportToExcel(dataGridView3);
        }
    }
}
